page

package
v0.0.0-...-264d4c2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Generator

type Generator struct {
	// contains filtered or unexported fields
}

func NewGenerator

func NewGenerator(
	markdownPath string,
	HTMLPath string,
	fs afero.Fs,
	sectionResolver section.Resolver,
	hrefPathsResolver hrefpath.Resolver,
	assetPathsResolver relpath.Resolver,
	validations *validation.Registry,
) *Generator

func (*Generator) Generate

func (g *Generator) Generate() error

Generate generates an HTML page by projecting the markdown file into the HTML template.

func (*Generator) Validate

func (g *Generator) Validate() error

Validate triggers structural validation checks on the generated HTML content. Note: This must be called after a successful invocation of Generate().

Directories

Path Synopsis
html
validation/access
Package access checks whether external references found in generated HTML are reachable.
Package access checks whether external references found in generated HTML are reachable.
validation/htmlref
Package htmlref locates and classifies the references (the values of src and href attributes) found in generated HTML.
Package htmlref locates and classifies the references (the values of src and href attributes) found in generated HTML.
validation/jssyntax
Package jssyntax validates the syntax of local JavaScript files referenced by generated HTML.
Package jssyntax validates the syntax of local JavaScript files referenced by generated HTML.
validation/reference
Package reference validates the references (images, links, scripts) embedded in generated HTML.
Package reference validates the references (images, links, scripts) embedded in generated HTML.

Jump to